@@ -885,7 +885,13 @@ void PostScript_MetaHandler::ParsePSFile()
 					if (CheckBytes ( ioBuf.ptr, Uns8Ptr("iler"), 4 ))
 					{
 						ioBuf.ptr+=4;
-						while(!IsNewline(*ioBuf.ptr)) ++ioBuf.ptr;
+						// See bug https://bugs.freedesktop.org/show_bug.cgi?id=105206
+						// Ensure we don't get past the limit if
+						// the data is bogus.
+						while(ioBuf.ptr < ioBuf.limit &&
+						      !IsNewline(*ioBuf.ptr)) {
+							++ioBuf.ptr;
+						}
 						setTokenInfo(kPS_Trailer,begStartpos,ioBuf.filePos+ioBuf.ptr-ioBuf.data-begStartpos);
 					}
 				}
